@@ -49,10 +49,16 @@ var linterna_magica_options =
 	// configured.
 	// off/disabled/no/never/false/0: Do not check
 	"updates": "1w",
-	// Set which program has priority to play the video
-	// self: Replace the swf object
+	// This options determines how opbject found by Linterna Mágica
+	// should be played. You can set multiple values separated with
+	// ",", without the quotes. Default value is "html5, self,
+	// plugin".
+        // self: Replace the flash object
 	// plugin: Add link after the swf object that replaces it
-	"priority": "self",
+	// html5: Add link after the HTMl5 player (if a site provides
+	// one) that replaces it
+	// Default value "html5, self, plugin"
+	"priority": "html5, self, plugin",
 	// Automatically start the video playback
 	// enabled: Auto start the clip (default)
 	// disabled:  Do not start the clip
@@ -61,18 +67,38 @@ var linterna_magica_options =
 	// self: Use controls provided by Linterna Mágica (default)
 	// plugin: Use controls provided by the video plugin
 	"controls": "self",
+	// Interface language
+	// auto: Use the language of the browser interface if
+	// translation is available (default)
+	// <lc>_<CC>: Set language to lc_CC, where
+	// <lc>:  language code (lowercase)
+	//  <CC>: country code (uppercase)
+	// Example: en_US, en_UK, bg_BG
+	"locale": "auto",
 	// The way cookies are proccessed. The explanation is too long
 	// to fit here. Please ***read*** "A note on cookies", in the
 	// HELP file.
 	// delete: Just delete the cookies.
 	// restore: Extract and restore cookies.
 	"cookies": "restore",
-	// Timeout before background processing starts in Dailymotion in
+	// Timeout before background processing (XHR) starts  in
 	// milliseconds. 1 s = 1000 ms. If you have problems increase the
 	// value.
 	// off/no/disabled/false/0: Don't wait (defult)
         // <integer>: Wait for <integer> milliseconds.
-	"wait_dm": "off",
+	"wait_xhr": "off",
+	// Preferred video quality.
+	//
+	// low/medium/high: Automatically select the link for
+	// low/medium/high from the list of links (default low)
+	//
+	// <number>: Start the <number> link from the list. If not
+	// available the highest quality. Use "1" for lowest quality.
+	//
+	// <number>%: Start the link that corresponds to <number>
+	// percent from the list. Float numbers are allowed - 34.56%,
+	// 18,6%.
+	"quality": "low",
     };
 
 // NO MINIMISATION ABOVE THIS LINE
