@@ -3,7 +3,7 @@
 //
 //  This file is part of Linterna Mágica
 //
-//  Copyright (C) 2010, 2011  Ivaylo Valkov <ivaylo@e-valkov.org>
+//  Copyright (C) 2010, 2011, 2012  Ivaylo Valkov <ivaylo@e-valkov.org>
 //  Copyright (C) 2010  Anton Katsarov <anton@katsarov.org>
 //
 //  The JavaScript code in this page (or file) is free software: you
@@ -62,6 +62,7 @@ function(not_in_header,id,switch_type)
 	wrapper = document.createElement("p");
 	wrapper.appendChild(toggle_plugin);
 	wrapper.style.setProperty("position", "relative", "important");
+	wrapper.style.setProperty("z-index", "999999", "important");
     }
     else
     {
@@ -82,15 +83,17 @@ function(not_in_header,id,switch_type)
 
     if (/html5/i.test(switch_type))
     {
-	toggle_plugin.setAttribute("title",
-				   this._("Switch between site's HTML5 "+
-					  "player and Linterna Mágica"));
+	var title = this.
+	    _("Switch between site's HTML5 player and Linterna Mágica");
+
+	toggle_plugin.setAttribute("title", title);
     }
     else
     {
-	toggle_plugin.setAttribute("title",
-				   this._("Switch between flash plugin"+
-					  " and Linterna Mágica"));
+	var title = this.
+	    _("Switch between flash plugin and Linterna Mágica");
+
+	toggle_plugin.setAttribute("title",title);
     }
 
     return wrapper ? wrapper : toggle_plugin;
